#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/lirc-update.sh - update or generate new LIRC config
#
# Copyright (c) 2005 Alexander Dahl <post@lespocky.de>
#
# Creation:     02.07.2005  alex
# Last Update:  03.07.2005  alex
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

### define package
PACKAGE='lirc'
CONFIGFILE=/etc/config.d/$PACKAGE

### include eislib
. /var/install/include/eislib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    ADDED=0
    mecho -info "Adding new parameter(s)..."
    
    if ! grep -q ^LIRC_DRIVER $SOURCE_CONF
    then
        LIRC_DRIVER='serial'
        mecho -std "- LIRC_DRIVER='$LIRC_DRIVER'"
        ADDED=1
    fi
    
    if [ $ADDED -eq 1 ]
    then
        mecho -warn "...read documentation for new parameter(s)!"
        anykey
    else
        mecho -std "...nothing to do."
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    MODIFIED=0
    mecho -info "Modifying parameter(s)..."
    
    if [ ! $LIRC_DEVICE = '' ]
    then
        case $LIRC_DEVICE in
            com1)
                LIRC_DRIVER_OPTION='/dev/ttyS0'
                mecho -std "- LIRC_DRIVER_OPTION='$LIRC_DRIVER_OPTION'"
            ;;
            com2)
                LIRC_DRIVER_OPTION='/dev/ttyS1'
                mecho -std "- LIRC_DRIVER_OPTION='$LIRC_DRIVER_OPTION'"
            ;;
            *)
                LIRC_DRIVER_OPTION=''
            ;;
        esac
        MODIFIED=1
    fi
        
    
    if [ $MODIFIED -eq 1 ]
    then
        mecho -warn "...read documentation for modified parameter(s)!"
        anykey
    else
        mecho -std "...nothing to do."
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho -info "Updating/creating configuration..."
    
    {
        echo '#------------------------------------------------------------------------------'
        echo '# /etc/config.d/lirc - LIRC configuration'
        echo '#'
        echo '# Copyright (c) 2005 Alexander Dahl <post@lespocky.de>'
        echo '#'
        echo '# Creation:     02.07.2005  alex'
        echo "# Last Update:  `date +%d.%m.%Y`  $LOGNAME"
        echo '#'
        echo '#------------------------------------------------------------------------------'
        echo
        echo '#------------------------------------------------------------------------------'
        echo '# General settings'
        echo '#------------------------------------------------------------------------------'
        echo
        printvar "START_LIRC"            "Start LIRC at boot: 'yes' or 'no'"
        echo
        printvar "LIRC_DRIVER"            "Driver Modul: 'none' or 'serial'"
        printvar "LIRC_DRIVER_OPTION"    "Driver Option, e.g. device for serial"
        echo
        echo
        echo '#------------------------------------------------------------------------------'
        echo '# End'
        echo '#------------------------------------------------------------------------------'
    } > $GENERATE_CONF
    
    mecho -std "...finished."
    anykey
}

#==============================================================================
# main
#==============================================================================

### setting defaults
SOURCE_CONF=$CONFIGFILE
GENERATE_CONF=$CONFIGFILE

if [ -f $SOURCE_CONF ]
then
    # previous configuration file exists
    mecho -info "Previous configuration found..."
    . $SOURCE_CONF
    
    modify_variables
    add_variables
    
    create_config
    
    # backup is done in edit script
else
    mecho -error "No configuration $SOURCE_CONF found - exiting."
    anykey
fi

exit 0
#==============================================================================
# end
#==============================================================================
